@@ -7,7 +7,7 @@ from pypans.file import Template
 from pypans.project import Project, User  # noqa: I100
 
 
-def _colored_output(string: str, color: str) -> int:
+def _write_as_colored(string: str, color: str) -> int:
     """Writes data into colored output.
 
     Returns number of characters to write.
@@ -38,11 +38,17 @@ class _Environment:
             os.system(f"git config --local user.email {self._user.email}")
             os.system(f"git remote add origin {to_repo}")
 
-        git: str = input(colored(">>> Would you like to setup git for a project? (yes/no): ", "green"))
+        git: str = input(
+            colored(f">>> Would you like to setup git for `{self._name}` project? (yes/no): ", color="green")
+        )
         if git == "yes":
-            prepare(to_repo=input(colored(">>> Please enter github repo (e.g git@github:user/project.git): ", "green")))
+            prepare(
+                to_repo=input(
+                    colored(">>> Please enter github repo (e.g git@github:user/project.git): ", color="green")
+                )
+            )
         else:
-            _colored_output(string=f"Project setup with git is skipped for `{self._name}` app", color="red")
+            _write_as_colored(string=f">>> 🚨 Setup with git is skipped for `{self._name}` project 🚨", color="red")
 
     def install_requirements(self) -> None:
         """Installs project requirements."""
@@ -50,12 +56,16 @@ class _Environment:
         def install_from(file: Template) -> None:  # noqa: VNE002
             os.system(f"pip install -r {file}")
 
-        install: str = input(colored(">>> Would you like to install project dependencies? (yes/no): ", "green"))
+        install: str = input(
+            colored(f">>> Would you like to install dependencies for `{self._name}` project? (yes/no): ", color="green")
+        )
         if install == "yes":
             install_from(file=Template.REQUIREMENTS)
             install_from(file=Template.DEV_REQUIREMENTS)
         else:
-            _colored_output(string=f"Dependencies installation is skipped for `{self._name}` app", color="red")
+            _write_as_colored(
+                string=f">>> 🚨 Dependencies installation is skipped for `{self._name}` project 🚨", color="red"
+            )
 
 
 def __build_environment(name: str, user: User) -> None:
@@ -64,6 +74,7 @@ def __build_environment(name: str, user: User) -> None:
     environment.setup_project()
     environment.setup_git()
     environment.install_requirements()
+    _write_as_colored(string=f">>> 🐍 Successfully created fresh `{name}` python project 🐍", color="magenta")
 
 
 @click.command()
@@ -74,6 +85,7 @@ def easypan(start: bool) -> None:
     Program allows to interactively compose fresh python project from template.
     """
     if start:
+        _write_as_colored(string=">>> 🥘 Welcome to `pypan` python project builder tool 🥘", color="green")
         __build_environment(
             name=input(colored(">>> Please name your application (e.g bomber): ", "green")).lower().replace("-", "_"),
             user=User(
@@ -81,7 +93,6 @@ def easypan(start: bool) -> None:
                 email=input(colored(">>> Please enter your email (e.g user@gmail.com): ", "green")),
             ),
         )
-        _colored_output(string=f"🐍 Successfully created fresh python project 🐍", color="magenta")
     else:
         click.echo(click.get_current_context().get_help())
 
